@@ -1,4 +1,3 @@
-# coding=utf-8
 from qrunner.running.runner import main
 from qrunner.case import TestCase, Page
 from qrunner.core.api.request import HttpRequest, ResponseResult
@@ -11,9 +10,9 @@ from qrunner.core.browser.driver import BrowserDriver
 from qrunner.core.browser.element import WebElement
 from qrunner.utils.log import logger
 from qrunner.utils.decorate import *
-from qrunner.utils.mock import mock, mock_en
+from qrunner.utils.mock import mock, mock_en, RandomData, CommonData
 from qrunner.utils.config import conf
 
-__version__ = "0.9.20"
+__version__ = "0.9.29"
 __description__ = "全栈自动化测试框架"
 
