@@ -9,6 +9,7 @@ from qrunner.utils.log import logger
 from qrunner.utils.config import conf
 from qrunner.core.android.driver import AndroidDriver
 from qrunner.utils.exceptions import NoSuchElementException
+from qrunner.utils.decorate import step
 
 
 class AndroidElement(object):
@@ -18,6 +19,7 @@ class AndroidElement(object):
     def __init__(self, driver=None, *args, **kwargs):
         # 从kwargs中删掉并返回index
         self._index = kwargs.pop('index', 0)
+        self.desc = kwargs.pop('desc', '')
         # 参数初始化
         self._xpath = kwargs.get('xpath', '')
         self._kwargs = kwargs
@@ -90,10 +92,8 @@ class AndroidElement(object):
         """
         element = self._find_element(retry=retry, timeout=timeout)
         if element is None:
-            self._driver.screenshot(f'{self._kwargs}-定位失败')
-            raise NoSuchElementException(f'{self._kwargs}-定位失败')
-        else:
-            self._driver.screenshot(f'{self._kwargs}-定位成功')
+            self._driver.screenshot(f'[控件 {self.desc} 定位失败]')
+            raise NoSuchElementException(f'[控件 {self.desc} 定位失败]')
         return element
 
     @property
@@ -165,7 +165,7 @@ class AndroidElement(object):
     def click_exists(self):
         logger.info(f'存在才点击元素: {self._kwargs},{self._index}')
         if self.exists():
-            self.get_element().click()
+            self.click()
 
     def click_gone(self):
         logger.info(f'等元素 {self._kwargs} 消失后再点击')
@@ -211,16 +211,5 @@ class AndroidElement(object):
         logger.info(f'往下滑动元素: {self._kwargs},{self._index}')
         self.get_element().swipe("down")
 
-    def screenshot(self):
-        logger.info(f'元素 {self._kwargs}截图')
-        file_name = list(self._kwargs.values())[0]
-        img_dir = os.path.join(os.getcwd(), 'images')
-        if os.path.exists(img_dir) is False:
-            os.mkdir(img_dir)
-        time_str = time.strftime('%m%d%H%M%S')
-        file_path = os.path.join(img_dir,
-                                 f'{file_name}-{time_str}.png')
-        logger.info(f'截图保存至: {file_path}')
-        self.get_element().screenshot().save(file_path)
 
 
