@@ -72,11 +72,14 @@ def request(func):
         if cookies != "":
             logger.debug(f"[cookies]:\n {json_util.dumps(cookies)} \n")
         if params != "":
-            logger.debug(f"[params]:\n {json_util.dumps(params)} \n")
+            logger.debug(f"[params-json]:\n {json_util.dumps(params)} \n")
+            logger.debug(f"[params-python]:\n {params} \n")
         if data != "":
-            logger.debug(f"[data]:\n {json_util.dumps(data)} \n")
+            logger.debug(f"[data-json]:\n {json_util.dumps(data)} \n")
+            logger.debug(f"[data-python]:\n {data} \n")
         if json != "":
-            logger.debug(f"[json]:\n {json_util.dumps(json)} \n")
+            logger.debug(f"[json-json]:\n {json_util.dumps(json)} \n")
+            logger.debug(f"[json-python]:\n {json_util.dumps(json)} \n")
 
         # running function
         r = func(*args, **kwargs)
