@@ -178,7 +178,7 @@ class IosDriver(object):
         img_dir = os.path.join(os.getcwd(), 'images')
         if os.path.exists(img_dir) is False:
             os.mkdir(img_dir)
-        time_str = time.strftime('%Y%m%d%H%M%S')
+        time_str = time.strftime('%Y年%m月%d日 %H时%M分%S秒')
         file_path = os.path.join(img_dir,
                                  f'{time_str}-{file_name}.png')
         logger.info(f'截图保存至: {file_path}')
@@ -187,7 +187,7 @@ class IosDriver(object):
         logger.info(f'截图上传至allure报告')
         allure.attach.file(file_path,
                            attachment_type=allure.attachment_type.PNG,
-                           name=f'{file_name}-{time_str}')
+                           name=f'{time_str}-{file_name}')
 
     # def upload_pic(self, filename):
     #     self.screenshot('tmp.png')
