@@ -3,6 +3,7 @@ from typing import Union
 from wda import Selector
 from qrunner.utils.log import logger
 from qrunner.utils.config import conf
+from qrunner.utils.decorate import step
 from qrunner.core.ios.driver import IosDriver
 from multiprocessing.dummy import Pool as ThreadPool
 from selenium.common.exceptions import NoSuchElementException
@@ -15,6 +16,7 @@ class IosElement(object):
     def __init__(self, driver=None, *args, **kwargs):
         # 从kwargs中删掉并返回index
         self._index = kwargs.pop('index', 0)
+        self.desc = kwargs.pop('desc', '')
         # 参数初始化
         self._xpath = kwargs.get('xpath', '')
         self._kwargs = kwargs
@@ -79,10 +81,8 @@ class IosElement(object):
         """
         element: Union[Selector] = self._find_element(retry=retry, timeout=timeout)
         if element is None:
-            self._driver.screenshot(f'元素: {self._kwargs}-定位失败')
-            raise NoSuchElementException(f'元素: {self._kwargs} 定位失败')
-        else:
-            self._driver.screenshot(f'元素: {self._kwargs}-定位成功')
+            self._driver.screenshot(f'[控件 {self.desc}] 定位失败')
+            raise NoSuchElementException(f'[控件 {self.desc}] 定位失败')
         return element
 
     @property
@@ -159,6 +159,7 @@ class IosElement(object):
         self.get_element().click()
 
     def click_exists(self):
+        logger.info(f'存在才点击元素: {self._kwargs},{self._index}')
         if self.exists():
             self.click()
 
