@@ -48,34 +48,67 @@ if __name__ == '__main__':
     qrunner.main(
         case_path = 'test_dir',
         platform='browser',
-        browser_name='chrome'
+        browser_name='chrome',
+        base_url='https://patents-pre.qizhidao.com'
     )
 """
 
-case_content_not_api = """
-from qrunner import TestCase
+case_content_android = """
+import qrunner
 
 
-class TestUiSample(TestCase):
+@qrunner.story('首页')
+class TestAdrSample(qrunner.TestCase):
+    
+    @qrunner.title('从首页进入我的页')
     def test_go_my(self):
-        self.click(resourceId='id/bottom_btn')
-        self.click(resourceId='id/bottom_view', index=3)
-        self.assertExist(text='我的订单')
-        self.screenshot('test.png')
+        self.click(resourceId='id/bottom_btn', desc='广告关闭按钮')
+        self.click(resourceId='id/bottom_view', index=3, desc='底部导航-我的')
+        self.assertText('我的订单', desc='我的订单标题')
+"""
+
+case_content_ios = """
+import qrunner
+
+
+@qrunner.story('首页')
+class TestIosSample(qrunner.TestCase):
+
+    @qrunner.title('从首页进入我的页')
+    def test_go_my(self):
+        self.click(label='我的', desc='底部导航-我的')
+        self.assertText('我的订单', desc='我的订单标题')
+"""
+
+case_content_web = """
+import qrunner
+
+
+@qrunner.story('专利检索')
+class TestWebSample(qrunner.TestCase):
+    
+    @qrunner.title('专利简单检索')
+    def test_patent_search(self):
+        self.open_url('https://patents-pre.qizhidao.com/', desc='专利首页')
+        self.set_text('无人机', xpath='//*[@id="driver-home-step1"]', desc='专利搜索框')
+        self.click(id_='driver-home-step2', desc='搜索按钮')
+        self.assertTitle('无人机专利检索-企知道', desc='专利搜索页')
 """
 
 case_content_api = """
-from qrunner import TestCase, file_data
+import qrunner
 
 
-class TestApiSample(TestCase):
+@qrunner.story('PC站首页')
+class TestApiSample(qrunner.TestCase):
 
-    @file_data('card_type', 'data.json')
+    @qrunner.title('查询PC站首页banner列表')
+    @qrunner.file_data('card_type', 'data.json')
     def test_getToolCardListForPc(self, card_type):
         path = '/api/qzd-bff-app/qzd/v1/home/getToolCardListForPc'
         pay_load = {"type": card_type}
         self.post(path, json=pay_load)
-        self.assertCode(0)
+        self.assertEq('code', 0)
 """
 
 require_content = """qrunner
@@ -93,13 +126,12 @@ data_content = """
 
 
 def init_scaffold_project(subparsers):
-    parser = subparsers.add_parser("create", help="Create a new project with template structure.")
-    parser.add_argument('-n', '--name', dest='name', type=str, default='my_pro', help='Specify new project name.')
-    parser.add_argument('-t', '--platform', dest='platform', type=str, default='api', help='测试平台: api、android、ios、browser')
+    parser = subparsers.add_parser("start", help="Create a new project with template structure.")
+    parser.add_argument('-t', '--platform', dest='platform', type=str, default='api', help='测试平台: api、android、ios、web')
     return parser
 
 
-def create_scaffold(project_name, platform):
+def create_scaffold(platform):
     """ create scaffold with specified project name.
     """
 
@@ -114,6 +146,7 @@ def create_scaffold(project_name, platform):
         msg = f"created file: {path}"
         print(msg)
 
+    project_name = f'{platform}_demo'
     create_folder(project_name)
     create_file(
         os.path.join(project_name, ".gitignore"),
@@ -143,8 +176,8 @@ def create_scaffold(project_name, platform):
             android_run_content,
         )
         create_file(
-            os.path.join(project_name, 'test_dir', "test_api_sample.py"),
-            case_content_not_api,
+            os.path.join(project_name, 'test_dir', "test_adr_sample.py"),
+            case_content_android,
         )
     elif platform == 'ios':
         create_file(
@@ -152,17 +185,17 @@ def create_scaffold(project_name, platform):
             ios_run_content,
         )
         create_file(
-            os.path.join(project_name, 'test_dir', "test_api_sample.py"),
-            case_content_not_api,
+            os.path.join(project_name, 'test_dir', "test_ios_sample.py"),
+            case_content_ios,
         )
-    elif platform == 'browser':
+    elif platform == 'web':
         create_file(
             os.path.join(project_name, "run.py"),
             browser_run_content,
         )
         create_file(
-            os.path.join(project_name, 'test_dir', "test_api_sample.py"),
-            case_content_not_api,
+            os.path.join(project_name, 'test_dir', "test_web_sample.py"),
+            case_content_web,
         )
     else:
         print(f'不支持的平台: {platform}')
@@ -177,5 +210,5 @@ def create_scaffold(project_name, platform):
 
 
 def main_scaffold_project(args):
-    sys.exit(create_scaffold(args.name, args.platform))
+    sys.exit(create_scaffold(args.platform))
 
