@@ -60,7 +60,7 @@ class Mail:
         rate = allure_data.get('rate')
 
         # 邮件内容
-        title = f'{title}-{time.strftime("%Y%m%d%H")}'
+        title = f'{title}({time.strftime("%m-%d %H:%M")})'
         body_str = '\n\n共 {0} 个用例，通过 {1} 个，失败 {2} 个，通过率 {3}%，详见: {4}'\
             .format(total, passed, fail, rate, report_url)
         msg_data = {
